
<div class="container-fluid" id="doc-page">

    <div class="row">
        <div class="col-12" id="doc-navigation">
            <p> Folders |
                <a href="{{ parent_folder }}/index">..</a>
                {% for folder in folders %}
                    | <a href="{{ base_folder }}/{{folder }}/index">{{ folder }}</a>
                    {% endfor %}
            </p>
            <p> Files
                {% for file in files %}
                     | <a href="{{ base_folder }}/{{file }}">{{ file }}</a>
                    {% endfor %}
            </p>
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body" id="doc-content">
                    {{ content | safe}}
                </div>
            </div>
        </div>
    </div>
</div>
