from osbot_fast_api.api.Fast_API import Fast_API


class CBR__Fast_API__Markdown(Fast_API):

    pass
    # def setup(self):
    #     #self.setup_server()
    #     super().setup()
    #     return self

