{#{% extends "layouts/base.html" %}#}
{% extends "layouts/empty-page.html" %}

    {% block title %} {{ title }} {% endblock %}

    <!-- Specific Page CSS goes HERE  -->
    {% block stylesheets %}{% endblock stylesheets %}

    {% block content %}
        {% include content_view %}

    {% endblock content %}

{% block javascripts %}{% endblock javascripts %}
